#
# spec file for package testng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           testng
Version:        7.4.0
Release:        4.2
Summary:        Java-based testing framework
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://testng.org/
Source0:        %{name}-%{version}.tar.xz
Source1:        pom.xml
Source2:        %{name}-build.xml
Patch0:         0001-Avoid-accidental-javascript-in-javadoc.patch
Patch1:         0002-Replace-bundled-jquery-with-CDN-link.patch
Patch2:         testng-CVE-2022-4065.patch
BuildRequires:  ant
BuildRequires:  beust-jcommander
BuildRequires:  bsh2
BuildRequires:  fdupes
BuildRequires:  google-guice
BuildRequires:  javapackages-local >= 6
BuildRequires:  jsr-305
BuildRequires:  junit
BuildRequires:  snakeyaml
BuildArch:      noarch

%description
TestNG is a testing framework inspired from JUnit and NUnit but introducing
some new functionality, including flexible test configuration, and
distributed test running.  It is designed to cover unit tests as well as
functional, end-to-end, integration, etc.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1

sed 's/@VERSION@/%{version}/' %{SOURCE1} > pom.xml
cp %{SOURCE2} build.xml

# remove any bundled libs, but not test resources
find ! -path "*/test/*" -name *.jar -print -delete
find -name *.class -delete

sed -i -e 's/DEV-SNAPSHOT/%{version}/' src/main/java/org/testng/internal/Version.java

cp -p ./src/main/java/*.dtd.html ./src/main/resources/.

%build
mkdir -p lib
build-jar-repository -s lib ant/ant beust-jcommander bsh2/bsh google-guice jsr305 junit snakeyaml
%{ant} jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar -a org.testng:testng::jdk15:

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc CHANGES.txt README.md
%license LICENSE.txt

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.txt

%changelog
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Nov 22 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * testng-CVE-2022-4065.patch
    + Issues in sanitization of zip files could lead to path
    traversal and potentially code execution (bsc#1205628,
    CVE-2022-4065)
* Wed Apr 27 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 7.4.0
  * Features:
    + Ability to be notified when a data provider fails, through
    a TestNG listener.
    TestNG already has a listener that will let you plug in your
    callbacks for the following with respect to a data provider
    (implement org.testng.IDataProviderListener interface)
    You can now use this listener to be notified when a data
    provider fails as well.
    + Add the ability to override explicitly included test methods
    if they belong to any excluded groups via the configuration
    property : overrideIncludedMethods
    + Reduced memory foot print when trying to run tests with
    larger projects.
    This is now a toggle feature which can be enabled via the
    JVM argument: -Dtestng.memory.friendly=true
  * Bug fixes:
    + GITHUB-2459: Support configurable start time - emailable
    report
    + GITHUB-2467: XmlTest does not copy the xmlClasses during clone
    + GITHUB-2469: Parameters added in XmlTest during
    AlterSuiteListener not available in SuiteListener
    + GITHUB-2296: Fix for assertEquals not working for sets as
    order is not guaranteed
    + GITHUB-2465: Fix bux where Strings.join returns empty String
    + GITHUB-1632: throwing SkipException sets iTestResult status to
    Failure instead of Skip
    + GITHUB-2456: Add onDataProviderFailure listener
    + GITHUB-2445: NPE in FailedReporter.java With Tests Created in
    Factory
    + GITHUB-2428: Configuration methods have the same test class
    instance when @Factory is being used
    + GITHUB-2440: Fixed an issue when case timeout returned an
    incorrect exception and effect the next other test case
    + GITHUB-2407: Adds "overrideIncludedMethods" to the global
    config as a command-line argument, which excludes explicitly
    included test methods if they belong to any excluded groups
    + GITHUB-2432: Rework MethodInheritance.fixMethodInheritance to
    "soft" dependencies
    + GITHUB-2429: Seggregate Dependency Injection out as a clear
    implementation
    + GITHUB-2435: getParameterIndex() always return 0 in test
    listener
    + GITHUB-2406: TestNG 7.3.0 transitive vulnerability
    CVE-2020-11022 and CVE-2020-11023 due to JQuery 3.4.1
    + GITHUB-2405: Regression: Using TestNG via Maven breaks when
    optional Guice dependency is unavailable
    + GITHUB-2427: Guice module (suite parent-module and test
    module) configure() method is called multiple times
    + GITHUB-2419: TestNG JUnit reports are not valid if system
    output contains XML tags
    + GITHUB-188: suite parallel="methods" does not work when there
    are multiple <test> tags in the testng.xml
    + GITHUB-346: When a method is annotated with both BeforeGroups
    and AfterGroups only AfterGroup is executed
    + GITHUB-2403: Suite.xml files attempt to make web request when
    suite references standard TestNG DTD using HTTP
    + GITHUB-2385: Make @Listeners can work for implemented
    interfaces and Inherited class
    + GITHUB-2053: MethodHelper.collectAndOrderMethods() Hangs when
    Parallel Instance and dependsOnGroups
    + GITHUB-2400: BeforeClass/Method (and AfterClass/Method)
    configuration methods that override default methods are
    invoked multiple times
    + GITHUB-2396: @Ignore on method level doesn't work as expected
    + GITHUB-2382: TestNG version should be specified in MANIFEST.MF
    + GITHUB-2096: 7.0.0-beta6 memory issues (regression)
    + GITHUB-2355: TestNG creates multiple Guice Module Instances
    + GITHUB-2374: Add file name to the warning message
    + GITHUB-2321: -Dtestng.thread.affinity=true do not work when
    running multiple instance of test in parallel
    + GITHUB-2363: JS error when switching theme
    + GITHUB-2361: No way to enforce @Test(singleThreaded = true)
    when test defined in base class
    + GITHUB-2343: Injectors are not reused when they share the same
    set of modules
    + GITHUB-2346: ITestResult attributes are null when retrieved by
    Listener onTestStart if test fails at BeforeMethod
    + GITHUB-2357: TestNG 7.3.0 transitive dependencies
- Fetch sources using source service instead of a script
- Build with java source and target levels 8
- Modified patches:
  * 0001-Avoid-accidental-javascript-in-javadoc.patch
  * 0002-Replace-bundled-jquery-with-CDN-link.patch
    + Rediff to changed context
* Sun Mar 17 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of testng 6.14.3
- Generate and customize ant build.xml file
